
# --------------------------------------------------------------------------------------------------------
#
#   STEP 2
#
#   Authorizing the 'teevity' IAM user to assume the TeevityPollerRole on all child accounts
#     (ie : execute this on the 'main account' used by Teevity, probably the one holding the S3 billing bucket)
#
#  Documentation
#    - Steps and policy for granting the 'teevity' IAM user access to the Roles on the 'child accounts'
#         http://docs.aws.amazon.com/IAM/latest/UserGuide/walkthru_cross-account-with-roles.html#walkthru_cross-account-with-roles-2
#    - CLI commands
#         
#
#  Testing
#    - Connecting as one of the 'Child account Roles' from the CLI
#         aws sts assume-role --role-arn "arn:aws:iam::450194722302:role/TeevityPollerRole" --role-session-name "TeevityTest-ChildAccounts"
#         http://docs.aws.amazon.com/IAM/latest/UserGuide/walkthru_cross-account-with-roles.html#walkthru_cross-account-with-roles-3
# --------------------------------------------------------------------------------------------------------

#
# ALTERNATIVE 1 - You have used AK/SK to connect Teevity to your AWS environmnent
#
# Allow AWS account "Teevity Root" to assume role 'TeevityPollerRole' on external account
# REMARK : This works even if the TeevityPollerRole has *not yet* been created on the child accounts, which
#          means that you can do that once and create, when the needs come, the Role on the child accounts.
aws iam put-user-policy --user-name "##TEEVITY_IAM_USERNAME##" --policy-name "CrossAccountPolicy" --policy-document "file://step2Dependency-teevityPolicyForTeevityIAMUserOrRoleOnMainAccountToAssumeTeevityPolerRoleOnChildAccounts.json"


#
# ALTERNATIVE 2 - You have used a Trust Account Relationship to connect Teevity to your AWS environment
#
# Allow the IAM Role on AWS "Teevity Root" account to assume role 'teevity-ice' on external account
# REMARK : This works even if the TeevityPollerRole has *not yet* been created on the child accounts, which
#          means that you can do that once and create, when the needs come, the Role on the child accounts.
aws iam put-role-policy --role-name "TeevityCrossAccountTrustRole" --policy-name "CrossAccountPolicy" --policy-document "file://step2Dependency-teevityPolicyForTeevityIAMUserOrRoleOnMainAccountToAssumeTeevityPolerRoleOnChildAccounts.json"
